//! dremu is a RISC-V 32-bits CPU emulator.

#![deny(
    warnings,
    missing_docs,
    clippy::all,
    clippy::missing_docs_in_private_items,
    rustdoc::missing_crate_level_docs
)]

use core::isa::hart::RVHart;
use devices::memory_unit::MemoryUnit;

pub mod core;
pub mod devices;

fn main() {
    let program_data: [u8; 8] = [
        0x93, 0x80, 0x00, 0x03, // addi x1, x1, 0x30
        0x67, 0x00, 0x00, 0x00, // jalr x0, 0(x0)
    ];

    let mut mem = MemoryUnit::new();
    mem.load_raw(&program_data);

    let mut cpu = RVHart::new();
    cpu.map_device(mem, 0x0);
    cpu.start_main_loop();
}
